# -*- coding: utf-8 -*-
# no-pylint: disable=missing-docstring,too-many-instance-attributes

import os
from pgbouncemgr.config import InvalidConfigValue


class NodeConfig():
    """NodeConfig holds the configuration for a single PostgreSQL node
       in the PostgreSQL cluster."""
    def __init__(self, node_id):
        self.node_id = node_id
        self._pgbouncer_config = None
        self.host = None
        self.port = None
        self.connect_timeout = 1
        self.name = 'template1'
        self.user = 'pgbouncemgr'
        self.password = None

    @property
    def pgbouncer_config(self):
        return self._pgbouncer_config

    @pgbouncer_config.setter
    def pgbouncer_config(self, path):
        if not os.path.exists(path):
            raise InvalidConfigValue(
                "pgbouncer_config path must exist",
                "nodes[%s]" % self.node_id, "pgbouncer_config", path)
        self._pgbouncer_config = path

    def export(self):
        """Exports the data for the node configuration, that we want
           to end up in the state data that is stored in the state store."""
        return {
            "pgbouncer_config": self.pgbouncer_config,
            "host": self.host,
            "port": self.port
        }
